from typing import List

import nh3

from ._Sanitizer import Sanitizer, T


class Nh3Sanitizer(Sanitizer):

    def _types_to_sanitize(self) -> List[type]:
        return [str]

    def _sanitize(self, value: T) -> T:
        if isinstance(value, str):
            return nh3.clean(value, tags=set())
        return value



from typing import List

from ._PropertyError import PropertyError


class UnionPropertyError(PropertyError):
    def __init__(self, property_name: str, inner_errors: List[PropertyError]):
        super().__init__(property_name, PropertyError.UNKNOWN_ERROR)
        self.inner_errors = inner_errors



from abc import abstractmethod, ABC
from typing import TypeVar, List

T = TypeVar('T')


class Sanitizer(ABC):

    @abstractmethod
    def _types_to_sanitize(self) -> List[type]:
        return []

    @abstractmethod
    def _sanitize(self, value):
        raise NotImplementedError()

    def sanitize(self, value: T) -> T:
        if type(value) in self._types_to_sanitize():
            return self._sanitize(value)
        return value



from typing import Dict, Tuple

from messageprocessor import MessageProcessor
from simplehttprouter import Route, SimpleHttpRouter, FoundRoute
from ._RouterProcessorBuilder import RouterProcessorBuilder


class SimpleHttpRouterRouterProcessorBuilder(RouterProcessorBuilder):
    def __init__(self, route_processor):
        # type: (Dict[Route, MessageProcessor]) -> None
        self.route_processor = route_processor
        self.router = SimpleHttpRouter(route_processor.keys())

    def get_processor(self, route):
        # type: (Route) -> Tuple[FoundRoute, MessageProcessor]
        found_route = self.router.get_route(route)
        return found_route, self.route_processor[found_route.route]
